==> foundation-2.6.1.tgz: package/SocialReddit/SocialReddit.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const SocialReddit = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M94.762 48.994c0-5.688-4.63-10.314-10.315-10.314-2.463 0-4.767.901-6.626 2.477-.06.037-.122.072-.181.11-6.707-4.291-15.601-7.031-25.439-7.403l5.872-16.698 14.656 3.504c.012 4.633 3.781 8.4 8.42 8.4 4.642 0 8.422-3.777 8.422-8.421 0-4.646-3.78-8.423-8.422-8.423-3.529 0-6.544 2.182-7.794 5.26l-17.364-4.15-7.211 20.49c-10.259.193-19.556 2.969-26.513 7.404-1.873-1.625-4.21-2.551-6.718-2.551-5.687 0-10.31 4.627-10.31 10.314 0 3.518 1.815 6.768 4.756 8.66a18.114 18.114 0 00-.293 3.123c0 14.886 18.043 26.997 40.219 26.997 22.18 0 40.224-12.111 40.224-26.997a18.14 18.14 0 00-.272-3.035c3.02-1.878 4.889-5.175 4.889-8.747zM63.598 62.347a6.333 6.333 0 01-6.334-6.338 6.337 6.337 0 116.334 6.338zm1.261 10.806c-.19.194-4.733 4.821-15.009 4.821-10.333 0-14.463-4.689-14.636-4.891a1.623 1.623 0 01.178-2.283 1.63 1.63 0 012.278.166c.092.104 3.54 3.771 12.18 3.771 8.784 0 12.639-3.798 12.68-3.835a1.62 1.62 0 012.329 2.251zm-34.05-17.144a6.337 6.337 0 1112.672.006 6.337 6.337 0 01-12.672-.006z"
  }));
});
SocialReddit.displayName = 'SocialReddit';
export const SocialRedditDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/SocialReddit/SocialReddit.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var SocialReddit = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M94.762 48.994c0-5.688-4.63-10.314-10.315-10.314-2.463 0-4.767.901-6.626 2.477-.06.037-.122.072-.181.11-6.707-4.291-15.601-7.031-25.439-7.403l5.872-16.698 14.656 3.504c.012 4.633 3.781 8.4 8.42 8.4 4.642 0 8.422-3.777 8.422-8.421 0-4.646-3.78-8.423-8.422-8.423-3.529 0-6.544 2.182-7.794 5.26l-17.364-4.15-7.211 20.49c-10.259.193-19.556 2.969-26.513 7.404-1.873-1.625-4.21-2.551-6.718-2.551-5.687 0-10.31 4.627-10.31 10.314 0 3.518 1.815 6.768 4.756 8.66a18.114 18.114 0 00-.293 3.123c0 14.886 18.043 26.997 40.219 26.997 22.18 0 40.224-12.111 40.224-26.997a18.14 18.14 0 00-.272-3.035c3.02-1.878 4.889-5.175 4.889-8.747zM63.598 62.347a6.333 6.333 0 01-6.334-6.338 6.337 6.337 0 116.334 6.338zm1.261 10.806c-.19.194-4.733 4.821-15.009 4.821-10.333 0-14.463-4.689-14.636-4.891a1.623 1.623 0 01.178-2.283 1.63 1.63 0 012.278.166c.092.104 3.54 3.771 12.18 3.771 8.784 0 12.639-3.798 12.68-3.835a1.62 1.62 0 012.329 2.251zm-34.05-17.144a6.337 6.337 0 1112.672.006 6.337 6.337 0 01-12.672-.006z"
  }));
});
SocialReddit.displayName = 'SocialReddit';
export var SocialRedditDimensions = {
  height: 100,
  width: 100
};
